"""Rule execution engine.

Pure domain layer - executes rules to detect threats.
All components are stateless with no I/O operations.
"""

from raxe.domain.engine.executor import Detection, RuleExecutor, ScanResult
from raxe.domain.engine.matcher import Match, PatternMatcher

__all__ = [
    "Detection",
    "Match",
    "PatternMatcher",
    "RuleExecutor",
    "ScanResult",
]
