"""
Database Infrastructure - SQLite & Persistence

Modules (to be implemented):
    - sqlite_queue.py: Event queue for telemetry
    - migrations.py: Schema migrations (Alembic-style)
    - models.py: SQLAlchemy models
"""

__all__ = []
